#
# spec file for package bsd-games
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bsd-games
Version:        2.17
Release:        124.2
Summary:        Several Text-Mode Games
License:        BSD-3-Clause
Group:          Amusements/Games/Other
URL:            http://www.advogato.org/proj/bsd-games/
Source:         ftp://metalab.unc.edu/pub/Linux/games/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM bsd-games-2.17.diff
Patch0:         %{name}-%{version}.diff
# PATCH-FIX-UPSTREAM bsd-games-2.17-inc.diff
Patch1:         %{name}-%{version}-inc.diff
# PATCH-FIX-UPSTREAM bsd-games-2.17-ppc64.diff
Patch2:         %{name}-%{version}-ppc64.diff
# PATCH-FIX-UPSTREAM bsd-games-2.17-strictaliasing.diff
Patch3:         %{name}-%{version}-strictaliasing.diff
# PATCH-FIX-UPSTREAM bsd-games-2.17-execl.diff
Patch4:         %{name}-%{version}-execl.diff
# PATCH-FIX-UPSTREAM bsd-games-2.17-codecleanup.diff
Patch5:         %{name}-%{version}-codecleanup.diff
# PATCH-FIX-UPSTREAM hunt-64bit.patch
Patch7:         hunt-64bit.patch
# PATCH-FIX-UPSTREAM bsd-games-2.17-compile.patch
Patch8:         %{name}-%{version}-compile.patch
# PATCH-FIX-UPSTREAM bsd-games-2.17-gcc4.3.diff
Patch9:         %{name}-%{version}-gcc4.3.diff
# PATCH-FIX-UPSTREAM fix building with gcc 14
Patch10:        bsd-games-gcc14.diff
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libopenssl-devel
BuildRequires:  words
BuildRequires:  pkgconfig(ncursesw)
Requires(pre):  user(games) group(games)

%description
This package provides these games: arithmetic, atc,
backgammon, battlestar, bcd, bog, caesar, canfield, cfscores, cribbage,
fish, fortune, hangman, hunt, mille, monop, morse, number,
paranoia, pom, ppt, primes, rain, robots, sail, snake, snscore,
teachgammon, trek, wargames, worm, worms, and wump.

%prep
%setup -q -n bsd-games-%{version}
%patch -P 0
%patch -P 1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5
%patch -P 7
%patch -P 8
%patch -P 9
%patch -P 10 -p1

%build
# easier than patching :-)
sed -i -e 's#/usr/share/dict/words#/var/lib/dict/words#' configure

(echo %{buildroot}
echo "fortune factor cribbage mille robots"		# don't build fortune; factor is in coreutils, cribbage, robots  and mille fail
echo
echo "%{_bindir}"					# use bindir instead of /usr/games
for i in {1..9}; do echo; done	    			# 9 times default
echo "n" 						# Set owners/groups on installed files
yes "") | ./configure
make CC="gcc" CXX="g++" OPTIMIZE="%{optflags} $(pkg-config --cflags-only-I ncursesw) -DNCURSES_WIDECHAR" \
	dab_CXXFLAGS="-DHAVE_fgetln" %{?_smp_mflags} NCURSES_LIB="$(pkg-config --libs ncursesw)"

%install
make INSTALL_PREFIX=%{buildroot} install SBINDIR="%{_bindir}"
# get rid of dm functionality as it needs a setgid, dm is only used to restrict which games may be played

rm %{buildroot}%{_bindir}/dm

rm -Rf %{buildroot}%{_mandir}/man5 %{buildroot}%{_mandir}/man8

find %{buildroot}%{_localstatedir}/games/ -exec chmod g-w,o-rw {} \;
rm %{buildroot}%{_datadir}/doc/bsd-games/trek.me

# avoid conflict with mono-devel
mv %{buildroot}%{_bindir}/monop           %{buildroot}%{_bindir}/monopoly
mv %{buildroot}%{_mandir}/man6/monop.6.gz %{buildroot}%{_mandir}/man6/monopoly.6.gz

# avoid conflict with the fish shell
mv %{buildroot}%{_bindir}/fish %{buildroot}%{_bindir}/fish-game

%files
%license COPYING
%doc AUTHORS BUGS NEWS README SECURITY THANKS TODO YEAR2000
%{_bindir}/*
%{_mandir}/man6/*
%{_datadir}/misc/*
%{_datadir}/games/*
%dir %attr(770,games,games) %{_localstatedir}/games/hack
%dir %attr(770,games,games) %{_localstatedir}/games/phantasia
%dir %attr(770,games,games) %{_localstatedir}/games/sail
%attr(660,games,games) %{_localstatedir}/games/hack/data
%attr(660,games,games) %{_localstatedir}/games/hack/help
%attr(660,games,games) %{_localstatedir}/games/hack/hh
%attr(660,games,games) %{_localstatedir}/games/hack/perm
%attr(660,games,games) %{_localstatedir}/games/hack/record
%attr(660,games,games) %{_localstatedir}/games/hack/rumors
%attr(660,games,games) %{_localstatedir}/games/phantasia/characs
%attr(660,games,games) %{_localstatedir}/games/phantasia/gold
%attr(660,games,games) %{_localstatedir}/games/phantasia/lastdead
%attr(660,games,games) %{_localstatedir}/games/phantasia/mess
%attr(660,games,games) %{_localstatedir}/games/phantasia/monsters
%attr(660,games,games) %{_localstatedir}/games/phantasia/motd
%attr(660,games,games) %{_localstatedir}/games/phantasia/scoreboard
%attr(660,games,games) %{_localstatedir}/games/phantasia/void
%attr(660,games,games) %{_localstatedir}/games/atc_score
%attr(660,games,games) %{_localstatedir}/games/battlestar.log
%attr(660,games,games) %{_localstatedir}/games/cfscores
#%attr(660,games,games) %{_localstatedir}/games/criblog
#%attr(660,games,games) %{_localstatedir}/games/robots_roll
%attr(660,games,games) %{_localstatedir}/games/saillog
%attr(660,games,games) %{_localstatedir}/games/snake.log
%attr(660,games,games) %{_localstatedir}/games/snakerawscores
%attr(660,games,games) %{_localstatedir}/games/tetris-bsd.scores

%changelog
* Sat Nov  2 2024 Jan Engelhardt <jengelh@inai.de>
- Add bsd-games-gcc14.diff to resolve FTBFS
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jan  4 2019 Cristian Rodríguez <crrodriguez@opensuse.org>
- Switch to ncurses 6 wide char ABI
* Wed Oct 26 2016 kukuk@suse.de
- Replace %%pre section with prerequires of user and group games
* Wed Nov 25 2015 dimstar@opensuse.org
- Hack it up to get it to build:
  + Drop cribbage mille robots
- Do not build factor instead of building and then deleting it.
* Sun Nov 30 2014 mailaender@opensuse.org
- - Rename fish to fish-game to avoid conflict with fish (shell)
* Fri May  2 2014 seife+obs@b1-systems.com
- fix word list location for hangman and boggle
* Fri Oct  4 2013 sleep_walker@suse.cz
- remove /usr/games also from package description
* Fri Sep 27 2013 sleep_walker@suse.cz
- fix rot13 (bnc#827521)
- rework /usr/games/ --> /usr/bin move
* Mon Sep 23 2013 idonmez@suse.com
- Create games user/group on demand. fate#314560
* Fri May 31 2013 varkoly@suse.com
- Rename monop to monopoly to avoid conflict with mono-devel
* Wed Mar 27 2013 meissner@suse.com
- use Source URL.
- remove factor as it exists in coreutils.
* Tue Jan 29 2013 joop.boonen@opensuse.org
- Fixed SLES build
* Sun Jan 27 2013 joop.boonen@opensuse.org
- The binaries are now in /usr/bin like other games owned by root
- A more secure attr setup that afik cant be exploited any more
- Got rid of dm as it can cause a security issue, it not really
  needed to play the games
* Fri Jan 18 2013 mhrusecky@suse.cz
- dropping all permission scripts
* Wed Jan 16 2013 joop.boonen@opensuse.org
- run_permissions is obsolete, not supported in openSUSE > 12.2
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: use %%__cc, %%__cxx macros
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Tue Jun  2 2009 coolo@novell.com
- fix build with glibc 2.10
- add rpmlintrc to silence warnings
* Fri Aug 22 2008 lmichnovic@suse.cz
- compiling with -I/usr/include/ncurses
* Fri Feb  8 2008 meissner@suse.de
- replace name/host mismatch in utmpentry to fix gcc
  warning (copy and pasto)
* Fri Oct 26 2007 anicka@suse.cz
- fix for gcc 4.3
* Thu Aug  9 2007 anosek@suse.cz
- fixed build (compile.patch)
* Fri Aug  3 2007 anosek@suse.cz
- updated to version 2.17
  - added new game dab (Dots and Boxes)
  - bugfixes
* Fri Mar 30 2007 rguenther@suse.de
- add bison, flex and ncurses-devel BuildRequires
* Tue Aug 15 2006 anosek@suse.cz
- fixed Hunt not working on 64 bit [#199214] (hunt-64bit.patch)
* Sat May 27 2006 schwab@suse.de
- Don't strip binaries.
* Fri Apr 14 2006 mmarek@suse.cz
- fix typo in last fix (-p1 vs. -p0)
* Wed Apr 12 2006 mmarek@suse.cz
- fix two buffer overflows in scanf() calls, one in sail which is
  setgid games
  [#165465] (overflow.diff)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 11 2005 mmarek@suse.cz
- Fix strict aliasing once again for gcc-4.1
* Thu May 12 2005 meissner@suse.de
- fixed buffer overflow on 64bit platforms.
* Thu May 12 2005 meissner@suse.de
- use RPM_OPT_FLAGS
* Tue Apr 12 2005 pth@suse.de
- And another incomplete declaration fixed.
* Mon Apr  4 2005 pth@suse.de
- Fix incomplete struct declaration and thus make it compile with gcc >= 4
- Eliminate most compiler warnings.
* Sun Jan 23 2005 meissner@suse.de
- fixed execl* calls
* Fri Nov 12 2004 ro@suse.de
- fixed permission handling
* Tue Apr 27 2004 mmj@suse.de
- Fix strict aliasing
* Thu Oct 30 2003 ro@suse.de
- don't build as root
- package according to permissions.secure and call run_permissions
* Tue Sep 16 2003 ltinkl@suse.cz
- fix excessive setgid permissions (#30912)
* Tue May 27 2003 pmladek@suse.cz
- fixed installation of phantasia score files to do not produce
  unpackaged files
- uniffied the suffix of patches to .diff
* Tue Jul 30 2002 kukuk@suse.de
- use group games instead of game
* Wed Jul 10 2002 olh@suse.de
- add bsd-games-2.13-ppc64.diff, text is not a valid function name
* Wed Dec 12 2001 pmladek@suse.cz
- updated to version 2.13
- package renamed from bsdgames to bsd-games
* Fri May 25 2001 pmladek@suse.cz
- fixed includes on ia64
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Mon Feb 12 2001 ro@suse.de
- define timerclear if undef in huntd/ctl_transact
* Sun Oct  1 2000 kukuk@suse.de
- Remove termcap from need for build
- Fix sail for compiling with glibc 2.2
* Thu Jun  8 2000 vinil@suse.cz
- file list changed
* Fri Jun  2 2000 vinil@suse.cz
- fortune excluded
- group and set-gid for games
* Tue May 23 2000 vinil@suse.cz
- update to version 2.11 (major file relocations, because of FHS)
- buildroot added
* Fri Mar  3 2000 ro@suse.de
- use macro for mandir
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Oct  2 1998 ro@suse.de
- adventure: no more -traditional-cpp
- configure: use bsd-lib only if it's there
- dm/dm.c:   dont try to include nlist for glibc
- phantasia/phantglobs.h: dont redeclare strcpy et. al. for glibc
- sail/extern.h:          dito
* Fri Sep 18 1998 max@suse.de
- added some files to the filelist
* Fri Oct 24 1997 max@suse.de
- moved from Version 1.3 to 1.5
- prepared for autobuild
- corrected some paths
